==> apache-plc4x-0.11.0-source-release.zip: apache-plc4x-0.11.0/sandbox/plc4py/plc4py/protocols/modbus/readwrite/ModbusPDUReadFifoQueueResponse.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

from dataclasses import dataclass

from plc4py.api.messages.PlcMessage import PlcMessage
from plc4py.protocols.modbus.readwrite.ModbusPDU import ModbusPDU
from plc4py.protocols.modbus.readwrite.ModbusPDU import ModbusPDUBuilder
from plc4py.spi.generation.ReadBuffer import ReadBuffer
from plc4py.spi.generation.WriteBuffer import WriteBuffer
from typing import List
import math


@dataclass
class ModbusPDUReadFifoQueueResponse(PlcMessage, ModbusPDU):
    fifo_value: List[int]
    # Accessors for discriminator values.
    error_flag: bool = False
    function_flag: int = 0x18
    response: bool = True

    def __post_init__(self):
        super().__init__()

    def serialize_modbus_pdu_child(self, write_buffer: WriteBuffer):
        write_buffer.push_context("ModbusPDUReadFifoQueueResponse")

        # Implicit Field (byte_count) (Used for parsing, but its value is not stored as it's implicitly given by the objects content)
        byte_count: int = (int(len(self.fifo_value)) * int(2)) + int(2)
        write_buffer.write_unsigned_short(byte_count, logical_name="byteCount")

        # Implicit Field (fifo_count) (Used for parsing, but its value is not stored as it's implicitly given by the objects content)
        fifo_count: int = (int(len(self.fifo_value)) * int(2)) / int(2)
        write_buffer.write_unsigned_short(fifo_count, logical_name="fifoCount")

        # Array Field (fifoValue)
        write_buffer.write_simple_array(
            self.fifo_value, write_unsigned_short, logical_name="fifoValue"
        )

        write_buffer.pop_context("ModbusPDUReadFifoQueueResponse")

    def length_in_bytes(self) -> int:
        return int(math.ceil(float(self.get_length_in_bits() / 8.0)))

    def get_length_in_bits(self) -> int:
        length_in_bits: int = super().get_length_in_bits()
        _value: ModbusPDUReadFifoQueueResponse = self

        # Implicit Field (byteCount)
        length_in_bits += 16

        # Implicit Field (fifoCount)
        length_in_bits += 16

        # Array field
        if self.fifo_value != None:
            length_in_bits += 16 * len(self.fifo_value)

        return length_in_bits

    @staticmethod
    def static_parse_builder(read_buffer: ReadBuffer, response: bool):
        read_buffer.push_context("ModbusPDUReadFifoQueueResponse")

        byte_count: int = read_implicit_field("byteCount", read_unsigned_int)

        fifo_count: int = read_implicit_field("fifoCount", read_unsigned_int)

        self.fifo_value = read_count_array_field(
            "fifoValue", read_unsigned_int, fifo_count
        )

        read_buffer.pop_context("ModbusPDUReadFifoQueueResponse")
        # Create the instance
        return ModbusPDUReadFifoQueueResponseBuilder(fifo_value)

    def equals(self, o: object) -> bool:
        if self == o:
            return True

        if not isinstance(o, ModbusPDUReadFifoQueueResponse):
            return False

        that: ModbusPDUReadFifoQueueResponse = ModbusPDUReadFifoQueueResponse(o)
        return (self.fifo_value == that.fifo_value) and super().equals(that) and True

    def hash_code(self) -> int:
        return hash(self)

    def __str__(self) -> str:
        write_buffer_box_based: WriteBufferBoxBased = WriteBufferBoxBased(True, True)
        try:
            write_buffer_box_based.writeSerializable(self)
        except SerializationException as e:
            raise RuntimeException(e)

        return "\n" + str(write_buffer_box_based.get_box()) + "\n"


@dataclass
class ModbusPDUReadFifoQueueResponseBuilder(ModbusPDUBuilder):
    fifoValue: List[int]

    def __post_init__(self):
        pass

    def build(
        self,
    ) -> ModbusPDUReadFifoQueueResponse:
        modbus_pdu_read_fifo_queue_response: ModbusPDUReadFifoQueueResponse = (
            ModbusPDUReadFifoQueueResponse(self.fifo_value)
        )
        return modbus_pdu_read_fifo_queue_response

==> apache-plc4x-0.12.0-source-release.zip: apache-plc4x-0.12.0/sandbox/plc4py/plc4py/protocols/modbus/readwrite/ModbusPDUReadFifoQueueResponse.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

from dataclasses import dataclass

from plc4py.api.exceptions.exceptions import PlcRuntimeException
from plc4py.api.exceptions.exceptions import SerializationException
from plc4py.api.messages.PlcMessage import PlcMessage
from plc4py.protocols.modbus.readwrite.ModbusPDU import ModbusPDU
from plc4py.spi.generation.ReadBuffer import ReadBuffer
from plc4py.spi.generation.WriteBuffer import WriteBuffer
from typing import Any
from typing import ClassVar
from typing import List
import math


@dataclass
class ModbusPDUReadFifoQueueResponse(ModbusPDU):
    fifo_value: List[int]
    # Accessors for discriminator values.
    error_flag: ClassVar[bool] = False
    function_flag: ClassVar[int] = 0x18
    response: ClassVar[bool] = True

    def serialize_modbus_pdu_child(self, write_buffer: WriteBuffer):
        write_buffer.push_context("ModbusPDUReadFifoQueueResponse")

        # Implicit Field (byte_count) (Used for parsing, but its value is not stored as it's implicitly given by the objects content)
        byte_count: int = (int(len(self.fifo_value)) * int(2)) + int(2)
        write_buffer.write_unsigned_short(byte_count, logical_name="byteCount")

        # Implicit Field (fifo_count) (Used for parsing, but its value is not stored as it's implicitly given by the objects content)
        fifo_count: int = (int(len(self.fifo_value)) * int(2)) / int(2)
        write_buffer.write_unsigned_short(fifo_count, logical_name="fifoCount")

        # Array Field (fifoValue)
        write_buffer.write_simple_array(
            self.fifo_value, write_buffer.write_unsigned_short, logical_name="fifoValue"
        )

        write_buffer.pop_context("ModbusPDUReadFifoQueueResponse")

    def length_in_bytes(self) -> int:
        return int(math.ceil(float(self.length_in_bits() / 8.0)))

    def length_in_bits(self) -> int:
        length_in_bits: int = super().length_in_bits()
        _value: ModbusPDUReadFifoQueueResponse = self

        # Implicit Field (byteCount)
        length_in_bits += 16

        # Implicit Field (fifoCount)
        length_in_bits += 16

        # Array field
        if self.fifo_value is not None:
            length_in_bits += 16 * len(self.fifo_value)

        return length_in_bits

    @staticmethod
    def static_parse_builder(read_buffer: ReadBuffer, response: bool):
        read_buffer.push_context("ModbusPDUReadFifoQueueResponse")

        byte_count: int = read_buffer.read_unsigned_short(
            logical_name="byteCount", response=response
        )

        fifo_count: int = read_buffer.read_unsigned_short(
            logical_name="fifoCount", response=response
        )

        fifo_value: List[Any] = read_buffer.read_array_field(
            logical_name="fifoValue",
            read_function=read_buffer.read_unsigned_short,
            count=fifo_count,
            response=response,
        )

        read_buffer.pop_context("ModbusPDUReadFifoQueueResponse")
        # Create the instance
        return ModbusPDUReadFifoQueueResponseBuilder(fifo_value)

    def equals(self, o: object) -> bool:
        if self == o:
            return True

        if not isinstance(o, ModbusPDUReadFifoQueueResponse):
            return False

        that: ModbusPDUReadFifoQueueResponse = ModbusPDUReadFifoQueueResponse(o)
        return (self.fifo_value == that.fifo_value) and super().equals(that) and True

    def hash_code(self) -> int:
        return hash(self)

    def __str__(self) -> str:
        pass
        # write_buffer_box_based: WriteBufferBoxBased = WriteBufferBoxBased(True, True)
        # try:
        #    write_buffer_box_based.writeSerializable(self)
        # except SerializationException as e:
        #    raise PlcRuntimeException(e)

        # return "\n" + str(write_buffer_box_based.get_box()) + "\n"


@dataclass
class ModbusPDUReadFifoQueueResponseBuilder:
    fifo_value: List[int]

    def build(
        self,
    ) -> ModbusPDUReadFifoQueueResponse:
        modbus_pdu_read_fifo_queue_response: ModbusPDUReadFifoQueueResponse = (
            ModbusPDUReadFifoQueueResponse(self.fifo_value)
        )
        return modbus_pdu_read_fifo_queue_response
